@@ -9,8 +9,8 @@ use warnings;
 use Carp;
 use CHI;
 use File::Spec;
-use Locale::Places::Database::GB;
-use Locale::Places::Database::US;
+use Locale::Places::GB;
+use Locale::Places::US;
 use Module::Info;
 
 =encoding utf8
@@ -21,11 +21,11 @@ Locale::Places - Translate places between different languages using http://downl
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ London is Londres in French.
 Create a Locale::Places object.
 
 Takes one optional parameter, directory,
-which tells the object where to find the file GB.sql
+which tells the object where to directory containing GB.sql and US.sql
 If that parameter isn't given,
 the module will attempt to find the databases,
 but that can't be guaranteed.
@@ -63,16 +63,17 @@ sub new {
 
 	my $directory = delete $args{'directory'} || Module::Info->new_from_loaded(__PACKAGE__)->file();
 	$directory =~ s/\.pm$//;
+	$directory = File::Spec->catfile($directory, 'data');
 
 	Database::Abstraction::init({
-		directory => File::Spec->catfile($directory, 'databases'),
 		no_entry => 1,
 		cache => $args{cache} || CHI->new(driver => 'Memory', datastore => {}),
-		cache_duration => '1 week',
-		%args
+		cache_duration => $args{'cache_duration'} || '1 week',
+		%args,
+		directory => $directory
 	});
 
-	return bless { }, $class;
+	return bless { directory => $directory }, $class;
 }
 
 =head2 translate
@@ -146,10 +147,10 @@ sub translate {
 	my $db;
 
 	if(defined($country) && ($country eq 'US')) {
-		$self->{'US'} ||= Locale::Places::Database::US->new();
+		$self->{'US'} ||= Locale::Places::US->new(directory => $self->{'directory'});
 		$db = $self->{'US'};
 	} else {
-		$self->{'GB'} ||= Locale::Places::Database::GB->new();
+		$self->{'GB'} ||= Locale::Places::GB->new(directory => $self->{'directory'});
 		$db = $self->{'GB'};
 	}
 
